@@ -41,6 +41,6 @@ class TraceService:
 
     @classmethod
     def get_os(cls, request):
-        user_agent = request.META["HTTP_USER_AGENT"]
+        user_agent = request.META.get("HTTP_USER_AGENT")
         os = httpagentparser.simple_detect(user_agent)[0]
         return os
